==> ejc-budgetmanage-impl-3.0.0-20220407.084509-69-sources.jar: com/ejianc/business/change/bean/ChangesubpachagematerialanalysisEntity.java <==
package com.ejianc.business.change.bean;

import java.util.List;
import java.util.ArrayList;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 分包施工图预算材料分析变更
 * 
 * @author generator
 * 
 */
 @TableName("ejc_change_budgetmanage_subpachagematerialanalysis")
public class ChangesubpachagematerialanalysisEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="bill_code")
    private java.lang.String billCode; // 单据编号
    @TableField(value="original_id")
    private java.lang.Long originalId; // 原始单据id
    @TableField(value="project_id")
    private java.lang.Long projectId; // 项目id
    @TableField(value="project_name")
    private java.lang.String projectName; // 项目名称
    @TableField(value="change_reason")
    private java.lang.String changeReason; // 变更原因
    @TableField(value="effect_date")
    private java.util.Date effectDate; // 生效时间
    @TableField(value="contract_id")
    private java.lang.Long contractId; // 合同id
    @TableField(value="contract_name")
    private java.lang.String contractName; // 合同名称
    @TableField(value="total")
    private java.lang.Double total;//合计汇总数量
    @TableField(value="bill_state")
    private java.lang.Integer billState;//单据状态
    
    
    @TableField(exist=false)
    @SubEntity(serviceName="changesubpackmateanalydetailService",pidName = "mid")
    private List<ChangesubpackmateanalydetailEntity> subpackagematerialanalysisdetailEntities = new ArrayList<>(); // 分包施工图预算材料分析变更子表
    

    /**
     * 单据编号
     */
    public java.lang.String getBillCode() {
        return billCode;
    }

    /**
     * 单据编号
     */
    public void setBillCode(java.lang.String billCode) {
        this.billCode = billCode;
    }
    /**
     * 原始单据id
     */
    public java.lang.Long getOriginalId() {
        return originalId;
    }

    /**
     * 原始单据id
     */
    public void setOriginalId(java.lang.Long originalId) {
        this.originalId = originalId;
    }
    /**
     * 项目id
     */
    public java.lang.Long getProjectId() {
        return projectId;
    }

    /**
     * 项目id
     */
    public void setProjectId(java.lang.Long projectId) {
        this.projectId = projectId;
    }
    /**
     * 项目名称
     */
    public java.lang.String getProjectName() {
        return projectName;
    }

    /**
     * 项目名称
     */
    public void setProjectName(java.lang.String projectName) {
        this.projectName = projectName;
    }
    /**
     * 变更原因
     */
    public java.lang.String getChangeReason() {
        return changeReason;
    }

    /**
     * 变更原因
     */
    public void setChangeReason(java.lang.String changeReason) {
        this.changeReason = changeReason;
    }
    /**
     * 生效时间
     */
    public java.util.Date getEffectDate() {
        return effectDate;
    }

    /**
     * 生效时间
     */
    public void setEffectDate(java.util.Date effectDate) {
        this.effectDate = effectDate;
    }
    /**
     * 合同id
     */
    @ReferSerialTransfer(referCode="ejc-zjkj-outcontract")
    public java.lang.Long getContractId() {
        return contractId;
    }

    /**
     * 合同id
     */
    @ReferDeserialTransfer
    public void setContractId(java.lang.Long contractId) {
        this.contractId = contractId;
    }
    /**
     * 合同名称
     */
    public java.lang.String getContractName() {
        return contractName;
    }

    /**
     * 合同名称
     */
    public void setContractName(java.lang.String contractName) {
        this.contractName = contractName;
    }

    public List<ChangesubpackmateanalydetailEntity> getSubpackagematerialanalysisdetailEntities() {
        return subpackagematerialanalysisdetailEntities;
    }

    public void setSubpackagematerialanalysisdetailEntities(List<ChangesubpackmateanalydetailEntity> subpackagematerialanalysisdetailEntities) {
        this.subpackagematerialanalysisdetailEntities = subpackagematerialanalysisdetailEntities;
    }

    public Double getTotal() {
        return total;
    }

    public void setTotal(Double total) {
        this.total = total;
    }

    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
}

==> ejc-budgetmanage-impl-3.0.0-20240528.015635-206-sources.jar: com/ejianc/business/change/bean/ChangesubpachagematerialanalysisEntity.java <==
package com.ejianc.business.change.bean;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

import java.util.ArrayList;
import java.util.List;

/**
 * 分包施工图预算材料分析变更
 * 
 * @author generator
 * 
 */
 @TableName("ejc_change_budgetmanage_subpachagematerialanalysis")
public class ChangesubpachagematerialanalysisEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="bill_code")
    private java.lang.String billCode; // 单据编号
    @TableField(value="original_id")
    private java.lang.Long originalId; // 原始单据id
    @TableField(value="project_id")
    private java.lang.Long projectId; // 项目id
    @TableField(value="project_name")
    private java.lang.String projectName; // 项目名称
    @TableField(value="change_reason")
    private java.lang.String changeReason; // 变更原因
    @TableField(value="effect_date")
    private java.util.Date effectDate; // 生效时间
    @TableField(value="contract_id")
    private java.lang.Long contractId; // 合同id
    @TableField(value="contract_name")
    private java.lang.String contractName; // 合同名称
    @TableField(value="total")
    private java.lang.Double total;//合计汇总数量
    @TableField(value="bill_state")
    private java.lang.Integer billState;//单据状态
    @TableField(value="org_id")
    private java.lang.Long orgId; // 所属组织id
    @TableField(value="org_name")
    private java.lang.String orgName; // 所属组织名称
    @TableField(value="project_department_id")
    private java.lang.Long projectDepartmentId; // 项目部id


    public void setProjectDepartmentId(Long projectDepartmentId) {
        this.projectDepartmentId = projectDepartmentId;
    }

    @TableField(exist=false)
    @SubEntity(serviceName="changesubpackmateanalydetailService",pidName = "mid")
    private List<ChangesubpackmateanalydetailEntity> subpackagematerialanalysisdetailEntities = new ArrayList<>(); // 分包施工图预算材料分析变更子表
    

    /**
     * 单据编号
     */
    public java.lang.String getBillCode() {
        return billCode;
    }

    /**
     * 单据编号
     */
    public void setBillCode(java.lang.String billCode) {
        this.billCode = billCode;
    }
    /**
     * 原始单据id
     */
    public java.lang.Long getOriginalId() {
        return originalId;
    }

    /**
     * 原始单据id
     */
    public void setOriginalId(java.lang.Long originalId) {
        this.originalId = originalId;
    }
    /**
     * 项目id
     */
    public java.lang.Long getProjectId() {
        return projectId;
    }

    /**
     * 项目id
     */
    public void setProjectId(java.lang.Long projectId) {
        this.projectId = projectId;
    }
    /**
     * 项目名称
     */
    public java.lang.String getProjectName() {
        return projectName;
    }

    /**
     * 项目名称
     */
    public void setProjectName(java.lang.String projectName) {
        this.projectName = projectName;
    }
    /**
     * 变更原因
     */
    public java.lang.String getChangeReason() {
        return changeReason;
    }

    /**
     * 变更原因
     */
    public void setChangeReason(java.lang.String changeReason) {
        this.changeReason = changeReason;
    }
    /**
     * 生效时间
     */
    public java.util.Date getEffectDate() {
        return effectDate;
    }

    /**
     * 生效时间
     */
    public void setEffectDate(java.util.Date effectDate) {
        this.effectDate = effectDate;
    }
    /**
     * 合同id
     */
    @ReferSerialTransfer(referCode="ejc-zjkj-outcontract")
    public java.lang.Long getContractId() {
        return contractId;
    }

    /**
     * 合同id
     */
    @ReferDeserialTransfer
    public void setContractId(java.lang.Long contractId) {
        this.contractId = contractId;
    }
    /**
     * 合同名称
     */
    public java.lang.String getContractName() {
        return contractName;
    }

    /**
     * 合同名称
     */
    public void setContractName(java.lang.String contractName) {
        this.contractName = contractName;
    }



    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }

    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }

    public Long getProjectDepartmentId() {
        return projectDepartmentId;
    }

    public List<ChangesubpackmateanalydetailEntity> getSubpackagematerialanalysisdetailEntities() {
        return subpackagematerialanalysisdetailEntities;
    }

    public void setSubpackagematerialanalysisdetailEntities(List<ChangesubpackmateanalydetailEntity> subpackagematerialanalysisdetailEntities) {
        this.subpackagematerialanalysisdetailEntities = subpackagematerialanalysisdetailEntities;
    }

    public Double getTotal() {
        return total;
    }

    public void setTotal(Double total) {
        this.total = total;
    }

    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
}
